============
ANYstructure
============

Save cost and time by efficient optimization and reporting!

ANYstructure is the ultimate steel structure design tool for plate fields and cylinders!
Weight optimization for all structures with machine learning capabilities.
Calculations are based on DNV standards and rules.

It is based on DNV standards and recommended practices.

The following is caluculated:

* Minimum plate thickness (DNV-OS-C101)
* Minimum section modulus of stiffener/plate (DNVGL-OS-C101)
* Minimum shear area (DNVGL-OS-C101)
* Buckling (DNVGL-RP-C201)or PULS (licenced DNV software)
* Buckling strength of shells DNV-RP-C202
* PULS buckling (DNV license needed)
* Machine learning buckling, PULS based
* Fatigue for plate/stiffener connection (DNVGL-RP-C203)

Loads are defined as follows:

* External surface loads defined by polynominal equations
* Tank loads are calculated automatically

Loads are combined according to DNVGL-OS-C101.

Installation
------------

The easiest way to install the package is via pip::

    $ pip install anystructure

Usage
-----

An entry point is defined. After installing on PIP, just type "ANYstructure" in the command window.

Alternatively run \_\_main\_\_.py

Documentation
-------------

Documentation is cointained in the tool. Help -> Open documentation.
